==> web2sms_0.1.1-6.tar.gz: web2sms-0.1.1/src/providers/message.hpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef MESSAGE_HPP
#define MESSAGE_HPP

// Local includes
#include "messagetype.hpp"
#include "contactinfo.hpp"

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class PROVIDERS_API Message
{
public:
  Message();
  Message(const ContactInfoList& receivers,
          const QString& text,
          const MessageType& messageType);

  void setReceivers(const ContactInfoList& receivers);
  ContactInfoList receivers() const;

  void setText(const QString& text);
  QString text() const;

  void setMessageType(const MessageType& messageType);
  MessageType messageType() const;

private:
  ContactInfoList m_receivers;
  QString m_text;
  MessageType m_messageType;
};

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // MESSAGE_HPP

==> web2sms_0.1.2-1.tar.gz: web2sms-0.1.2/src/providers/message.hpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef MESSAGE_HPP
#define MESSAGE_HPP

// Local includes
#include "messagetype.hpp"
#include "contactinfo.hpp"

// Global includes
#include <QtCore/QUuid>

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class PROVIDERS_API Message
{
public:
  Message();
  Message(const ContactInfoList& receivers,
          const QString& text,
          const MessageType& messageType);

  void setReceivers(const ContactInfoList& receivers);
  ContactInfoList receivers() const;

  void setText(const QString& text);
  QString text() const;

  void setMessageType(const MessageType& messageType);
  MessageType messageType() const;

  /// A unique id for this message (generated in the constructor)
  QUuid messageId() const;

private:
  ContactInfoList m_receivers;
  QString m_text;
  MessageType m_messageType;
  QUuid m_messageId;
};

//////////////////////////////////////////////////////////////////////////

Q_DECLARE_METATYPE(Message);

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // MESSAGE_HPP
